==> notify_to_slack-8.x-2.0.tar.gz: notify_to_slack/src/Form/SlackMessageEditForm.php <==
<?php

namespace Drupal\notify_to_slack\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Renderer;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * SlackMessage entity edit form.
 */
class SlackMessageEditForm extends SlackMessageFormBase implements ContainerInjectionInterface {

  /**
   * Renderer.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * SlackMessageEditForm constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity Manager.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entityTypeBundleInfo
   *   Entity Type Bundle Info.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config Factory.
   * @param \Drupal\Core\Render\Renderer $renderer
   *   Renderer.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, EntityTypeBundleInfoInterface $entityTypeBundleInfo, ConfigFactoryInterface $configFactory, Renderer $renderer) {
    parent::__construct($entityTypeManager, $entityTypeBundleInfo, $configFactory);
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
       $container->get('entity_type.manager'),
       $container->get('entity_type.bundle.info'),
       $container->get('config.factory'),
       $container->get('renderer')
     );

  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {

    $form = parent::form($form, $form_state);

    $operation_types = [
      'insert' => 'Insert',
      'update' => 'Update',
      'delete' => 'Delete',
    ];

    /** @var \Drupal\notify_to_slack\Entity\SlackMessage $slack_message */
    $slack_message = $this->entity;

    $entity_type = $slack_message->getAttachedEntityType();
    $token_tree = [
      '#theme' => 'token_tree_link',
      '#token_types' => [$entity_type],
      '#global_types' => TRUE,
    ];

    $rendered_token_tree = $this->renderer->render($token_tree);
    $slack_message_set = $slack_message->get('slack_message_set');

    foreach ($operation_types as $operation => $operation_label) {
      if ($operation == 'insert'){
        $op = 'inserted';
      }
      else {
        $op = $operation.'d';
      }
      $form[$operation] = [
        '#type' => 'details',
        '#title' => $this->t('@operation Operation', ['@operation' => $operation]),
        '#open' => TRUE,
      ];
      $form[$operation][$operation . '_state'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Enable Custom Slack Message'),
        '#description' => $this->t('Select checkbox to enable Slack notification on @entity_type @operation.', ['@entity_type' => $entity_type, '@operation' => $operation]),
        '#default_value' => !empty($slack_message_set) ? $slack_message_set[$operation]['state'] : FALSE,
      ];
      $form[$operation][$operation . '_message'] = [
        '#type' => 'textarea',
        '#title' => $this->t('@operation_label Message', ['@operation_label' => $operation_label]),
        '#description' => $this->t('Message to be send on @entity_type @operation. @token',
            [
              '@entity_type' => $entity_type,
              '@operation' => $operation,
              '@token' => $rendered_token_tree,
            ]
        ),
        '#default_value' => !empty($slack_message_set[$operation]['message']) ? $slack_message_set[$operation]['message'] : 'Content is '.$op,
        '#states' => [
          'visible' => [
            ':input[name= "'.$operation.'_state"]' => ['checked' => TRUE]
          ],
          'required' => [
            ':input[name= "'.$operation.'_state"]' => ['checked' => TRUE]
          ],
        ]
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);
    /** @var \Drupal\notify_to_slack\Entity\SlackMessage $slack_message */
    $slack_message = $this->getEntity();
    $slack_message->setSlackMessageSet($form_state);
    $slack_message->save();
    $this->messenger()->addMessage($this->t('Changes to the Slack Message set have been saved.'));
  }

}

==> notify_to_slack-8.x-2.3.tar.gz: notify_to_slack/src/Form/SlackMessageEditForm.php <==
<?php

namespace Drupal\notify_to_slack\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Renderer;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * SlackMessage entity edit form.
 */
class SlackMessageEditForm extends SlackMessageFormBase implements ContainerInjectionInterface {

  /**
   * Renderer.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * SlackMessageEditForm constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity Manager.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entityTypeBundleInfo
   *   Entity Type Bundle Info.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config Factory.
   * @param \Drupal\Core\Render\Renderer $renderer
   *   Renderer.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, EntityTypeBundleInfoInterface $entityTypeBundleInfo, ConfigFactoryInterface $configFactory, Renderer $renderer) {
    parent::__construct($entityTypeManager, $entityTypeBundleInfo, $configFactory);
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
       $container->get('entity_type.manager'),
       $container->get('entity_type.bundle.info'),
       $container->get('config.factory'),
       $container->get('renderer')
     );

  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {

    $form = parent::form($form, $form_state);

    $operation_types = [
      'insert' => 'Insert',
      'update' => 'Update',
      'delete' => 'Delete',
    ];

    /** @var \Drupal\notify_to_slack\Entity\SlackMessage $slack_message */
    $slack_message = $this->entity;

    $entity_type = $slack_message->getAttachedEntityType();
    $token_tree = [
      '#theme' => 'token_tree_link',
      '#token_types' => [$entity_type],
      '#global_types' => TRUE,
    ];

    $rendered_token_tree = $this->renderer->render($token_tree);
    $slack_message_set = $slack_message->get('slack_message_set');

    foreach ($operation_types as $operation => $operation_label) {
      if ($operation == 'insert') {
        $op = 'inserted';
      }
      else {
        $op = $operation . 'd';
      }
      $form[$operation] = [
        '#type' => 'details',
        '#title' => $this->t('@operation Operation', ['@operation' => $operation]),
        '#open' => TRUE,
      ];
      $form[$operation][$operation . '_state'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Enable Custom Slack Message'),
        '#description' => $this->t('Select checkbox to enable Slack notification on @entity_type @operation.', ['@entity_type' => $entity_type, '@operation' => $operation]),
        '#default_value' => !empty($slack_message_set) ? $slack_message_set[$operation]['state'] : FALSE,
      ];
      $form[$operation][$operation . '_message'] = [
        '#type' => 'textarea',
        '#title' => $this->t('@operation_label Message', ['@operation_label' => $operation_label]),
        '#description' => $this->t('Message to be send on @entity_type @operation. @token',
            [
              '@entity_type' => $entity_type,
              '@operation' => $operation,
              '@token' => $rendered_token_tree,
            ]
        ),
        '#default_value' => !empty($slack_message_set[$operation]['message']) ? $slack_message_set[$operation]['message'] : 'Content is ' . $op,
        '#states' => [
          'visible' => [
            ':input[name= "' . $operation . '_state"]' => ['checked' => TRUE],
          ],
          'required' => [
            ':input[name= "' . $operation . '_state"]' => ['checked' => TRUE],
          ],
        ],
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);
    /** @var \Drupal\notify_to_slack\Entity\SlackMessage $slack_message */
    $slack_message = $this->getEntity();
    $slack_message->setSlackMessageSet($form_state);
    $slack_message->save();
    $this->messenger()->addMessage($this->t('Changes to the Slack Message set have been saved.'));
  }

}
